@@ -52,7 +52,7 @@ saveAllMatchesAllOppositionIPLT20 <- function(dir=".",odir=".") {
               "Kings XI Punjab","Punjab Kings", 'Kochi Tuskers Kerala',"Kolkata Knight Riders",
               "Mumbai Indians", "Pune Warriors","Rajasthan Royals",
               "Royal Challengers Bangalore","Sunrisers Hyderabad","Gujarat Lions",
-              "Rising Pune Supergiants")
+              "Rising Pune Supergiants","Lucknow Super Giants","Gujarat Titans")
 
     matches <- NULL
     for(i in seq_along(teams)){
